@@ -4,6 +4,7 @@ require 'action_controller'
 require 'multi_json'
 
 require 'gon/base'
+require 'gon/env_finder'
 require 'gon/global'
 require 'gon/watch'
 require 'gon/request'
@@ -11,6 +12,7 @@ require 'gon/helpers'
 require 'gon/escaper'
 require 'gon/rabl'
 require 'gon/jbuilder'
+require 'gon/jbuilder/parser'
 require 'gon/json_dumper'
 
 # NOTE : ActionDispatch::Request#uuid appears only in Rails 3.2.1
@@ -116,13 +118,7 @@ class Gon
     end
 
     def public_method_name?(method)
-      public_methods.include?(
-        if RUBY_VERSION > '1.9'
-          method.to_s[0..-2].to_sym
-        else
-          method.to_s[0..-2]
-        end
-      )
+      public_methods.include?(method.to_s[0..-2].to_sym)
     end
 
     # JbuilderTemplate will not be defined if jbuilder is required
