@@ -20,6 +20,7 @@ describe Gon do
       Gon.int          = 1
       Gon.float        = 1.1
       Gon.string       = 'string'
+      Gon.symbol       = :symbol
       Gon.array        = [1, 'string']
       Gon.hash_var     = { :a => 1, :b => '2' }
       Gon.hash_w_array = { :a => [2, 3] }
@@ -89,17 +90,14 @@ describe Gon do
     before(:each) do
       Gon::Request.
         instance_variable_set(:@request_id, request.object_id)
-      expect(ActionView::Base.
-        instance_methods.
-        map(&:to_s).
-        include?('include_gon')).to eq(true)
+      expect(ActionView::Base.instance_methods).to include(:include_gon)
       @base = ActionView::Base.new
       @base.request = request
     end
 
     it 'outputs correct js with an integer' do
       Gon.int = 1
-      expect(@base.include_gon).to eq('<script type="text/javascript">' +
+      expect(@base.include_gon).to eq('<script>' +
                                     "\n//<![CDATA[\n" +
                                     'window.gon={};' +
                                     'gon.int=1;' +
@@ -109,7 +107,7 @@ describe Gon do
 
     it 'outputs correct js with a string' do
       Gon.str = %q(a'b"c)
-      expect(@base.include_gon).to eq('<script type="text/javascript">' +
+      expect(@base.include_gon).to eq('<script>' +
                                     "\n//<![CDATA[\n" +
                                     'window.gon={};' +
                                     %q(gon.str="a'b\"c";) +
@@ -120,7 +118,7 @@ describe Gon do
     it 'outputs correct js with a script string' do
       Gon.str = %q(</script><script>alert('!')</script>)
       escaped_str = "\\u003c/script\\u003e\\u003cscript\\u003ealert('!')\\u003c/script\\u003e"
-      expect(@base.include_gon).to eq('<script type="text/javascript">' +
+      expect(@base.include_gon).to eq('<script>' +
                                     "\n//<![CDATA[\n" +
                                     'window.gon={};' +
                                     %Q(gon.str="#{escaped_str}";) +
@@ -128,10 +126,20 @@ describe Gon do
                                   '</script>')
     end
 
+    it 'outputs correct js with an integer and type' do
+      Gon.int = 1
+      expect(@base.include_gon(type: true)).to eq('<script type="text/javascript">' +
+                                    "\n//<![CDATA[\n" +
+                                    'window.gon={};' +
+                                    'gon.int=1;' +
+                                    "\n//]]>\n" +
+                                  '</script>')
+    end
+
     it 'outputs correct js with an integer, camel-case and namespace' do
       Gon.int_cased = 1
       expect(@base.include_gon(camel_case: true, namespace: 'camel_cased')).to eq( \
-                                  '<script type="text/javascript">' +
+                                  '<script>' +
                                     "\n//<![CDATA[\n" +
                                     'window.camel_cased={};' +
                                     'camel_cased.intCased=1;' +
@@ -143,7 +151,7 @@ describe Gon do
     it 'outputs correct js with camel_depth = :recursive' do
       Gon.test_hash = { test_depth_one: { test_depth_two: 1 } }
       expect(@base.include_gon(camel_case: true, camel_depth: :recursive)).to eq( \
-                                  '<script type="text/javascript">' +
+                                  '<script>' +
                                     "\n//<![CDATA[\n" +
                                     'window.gon={};' +
                                     'gon.testHash={"testDepthOne":{"testDepthTwo":1}};' +
@@ -155,7 +163,7 @@ describe Gon do
     it 'outputs correct js with camel_depth = 2' do
       Gon.test_hash = { test_depth_one: { test_depth_two: 1 } }
       expect(@base.include_gon(camel_case: true, camel_depth: 2)).to eq( \
-                                  '<script type="text/javascript">' +
+                                  '<script>' +
                                     "\n//<![CDATA[\n" +
                                     'window.gon={};' +
                                     'gon.testHash={"testDepthOne":{"test_depth_two":1}};' +
@@ -167,7 +175,7 @@ describe Gon do
     it 'outputs correct js for an array with camel_depth = :recursive' do
       Gon.test_hash = { test_depth_one: [{ test_depth_two: 1 }, { test_depth_two: 2 }] }
       expect(@base.include_gon(camel_case: true, camel_depth: :recursive)).to eq( \
-                                  '<script type="text/javascript">' +
+                                  '<script>' +
                                     "\n//<![CDATA[\n" +
                                     'window.gon={};' +
                                     'gon.testHash={"testDepthOne":[{"testDepthTwo":1},{"testDepthTwo":2}]};' +
@@ -221,7 +229,7 @@ describe Gon do
 
     it 'outputs correct js with type text/javascript' do
       expect(@base.include_gon(need_type: true, init: true)).to eq( \
-                                  '<script type="text/javascript">' +
+                                  '<script>' +
                                     "\n//<![CDATA[\n" +
                                     'window.gon={};'\
                                     "\n//]]>\n" +
@@ -231,7 +239,7 @@ describe Gon do
 
     it 'outputs correct js with namespace check' do
       expect(@base.include_gon(namespace_check: true)).to eq( \
-                                  '<script type="text/javascript">' +
+                                  '<script>' +
                                     "\n//<![CDATA[\n" +
                                     'window.gon=window.gon||{};'\
                                     "\n//]]>\n" +
@@ -241,7 +249,7 @@ describe Gon do
 
     it 'outputs correct js without namespace check' do
       expect(@base.include_gon(namespace_check: false)).to eq( \
-                                  '<script type="text/javascript">' +
+                                  '<script>' +
                                     "\n//<![CDATA[\n" +
                                     'window.gon={};'\
                                     "\n//]]>\n" +
@@ -257,7 +265,7 @@ describe Gon do
       end
 
       it "does not raise an exception" do
-        expect { @base.include_gon }.to_not raise_error(Exception)
+        expect { @base.include_gon }.to_not raise_error
       end
 
       it 'outputs correct js' do
@@ -266,7 +274,7 @@ describe Gon do
 
       it 'outputs correct js with init' do
         expect(@base.include_gon(init: true)).to eq( \
-                                    '<script type="text/javascript">' +
+                                    '<script>' +
                                       "\n//<![CDATA[\n" +
                                       'window.gon={};'\
                                       "\n//]]>\n" +
@@ -289,10 +297,7 @@ describe Gon do
     end
 
     it 'is included in ActionView::Base as a helper' do
-      expect(ActionView::Base.
-        instance_methods.
-        map(&:to_s).
-        include?('include_gon_amd')).to eq(true)
+      expect(ActionView::Base.instance_methods).to include(:include_gon_amd)
     end
 
     it 'outputs correct js without variables' do
@@ -323,8 +328,8 @@ describe Gon do
   end
 
   it 'returns exception if try to set public method as variable' do
-    expect { Gon.all_variables = 123 }.to raise_error
-    expect { Gon.rabl = 123 }.to raise_error
+    expect { Gon.all_variables = 123 }.to raise_error(RuntimeError)
+    expect { Gon.rabl = 123 }.to raise_error(RuntimeError)
   end
 
   describe '#check_for_rabl_and_jbuilder' do
@@ -334,15 +339,15 @@ describe Gon do
     it 'should be able to handle ruby 1.8.7 style constants array (strings)' do
       constants_as_strings = Gon.constants.map(&:to_s)
       allow(Gon).to receive(:constants) { constants_as_strings }
-      expect { Gon.rabl 'spec/test_data/sample.rabl', :controller => controller }.not_to raise_error
-      expect { Gon.jbuilder 'spec/test_data/sample.json.jbuilder', :controller => controller }.not_to raise_error
+      expect { Gon.rabl :template => 'spec/test_data/sample.rabl', :controller => controller }.not_to raise_error
+      expect { Gon.jbuilder :template => 'spec/test_data/sample.json.jbuilder', :controller => controller }.not_to raise_error
     end
 
     it 'should be able to handle ruby 1.9+ style constants array (symbols)' do
       constants_as_symbols = Gon.constants.map(&:to_sym)
       allow(Gon).to receive(:constants) { constants_as_symbols }
-      expect { Gon.rabl 'spec/test_data/sample.rabl', :controller => controller }.not_to raise_error
-      expect { Gon.jbuilder 'spec/test_data/sample.json.jbuilder', :controller => controller }.not_to raise_error
+      expect { Gon.rabl :template => 'spec/test_data/sample.rabl', :controller => controller }.not_to raise_error
+      expect { Gon.jbuilder :template => 'spec/test_data/sample.json.jbuilder', :controller => controller }.not_to raise_error
     end
   end
 
@@ -350,8 +355,8 @@ describe Gon do
     @request ||= double 'request', :env => {}
   end
 
-  def wrap_script(content, type='text/javascript', cdata=true)
-    script = "<script type=\"#{type}\">"
+  def wrap_script(content, cdata=true)
+    script = "<script>"
     script << "\n//<![CDATA[\n" if cdata
     script << content
     script << "\n//]]>\n" if cdata
